@@ -1,6 +1,12 @@
 use darling::FromDeriveInput;
 
-use crate::Case;
+use super::{
+    Case,
+    definitions::{
+        Definitions,
+        and_then,
+    },
+};
 
 #[derive(Debug, FromDeriveInput)]
 #[darling(attributes(rschema))]
@@ -10,4 +16,8 @@ pub struct StructAttr {
 
     #[darling(default)]
     pub rename_all: Option<Case>,
+
+    #[darling(default)]
+    #[darling(and_then = "and_then")]
+    pub defs: Definitions,
 }
